@@ -287,8 +287,8 @@ Usage::
     search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
     ```
 """
-from mypy_boto3_ec2.client import EC2Client
-from mypy_boto3_ec2.paginator import (
+from .client import EC2Client
+from .paginator import (
     DescribeAddressesAttributePaginator,
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
@@ -390,8 +390,8 @@ from mypy_boto3_ec2.paginator import (
     SearchLocalGatewayRoutesPaginator,
     SearchTransitGatewayMulticastGroupsPaginator,
 )
-from mypy_boto3_ec2.service_resource import EC2ServiceResource
-from mypy_boto3_ec2.waiter import (
+from .service_resource import EC2ServiceResource
+from .waiter import (
     BundleTaskCompleteWaiter,
     ConversionTaskCancelledWaiter,
     ConversionTaskCompletedWaiter,
